/**
 * Sends JSON-RPC messages via web sockets.
 */
export declare class WSRPCClient {
    url: string;
    private _client;
    private _openPromise?;
    private _rpcId;
    private _getNextRequestId;
    constructor(url: string, opts?: {
        autoConnect?: boolean;
        reconnect?: boolean;
        reconnectInterval?: number;
        maxReconnects?: number;
        generateRequestId?: (method: string, params: object | any[]) => string;
    });
    /**
     * Gracefully closes the underlying web socket connection.
     */
    disconnect(): void;
    private _ensureConnectionAsync();
    /**
     * Sends a JSON-RPC message.
     * @param method RPC method name.
     * @param params Parameter object or array.
     * @returns A promise that will be resolved with the value of the result field (if any) in the
     *          JSON-RPC response message.
     */
    sendAsync<T>(method: string, params: object | any[]): Promise<T>;
}
